@@ -3,11 +3,12 @@
 #' Intercensal estimates of the resident population for Incorporated Places and
 #' Minor Civil Divisions: April 1, 2000 to July 1, 2010.
 #' @docType data
-#' @format A data frame containing \code{City}, \code{State}, \code{Lat},
-#'   \code{Long}, and population estimates from 2000 to 2010 (columns
-#'   \code{Pop2000} to \code{Pop2010}).
+#' @format A data frame containing `City`, `State`, `Lat`,
+#'   `Long`, and population estimates from 2000 to 2010 (columns
+#'   `Pop2000` to `Pop2010`).
+#' @family built in datasets
 #' @source The US Census Bureau:
-#'   \url{https://www.census.gov/data/datasets/time-series/demo/popest/intercensal-2000-2010-cities-and-towns.html}
+#'   <https://www.census.gov/data/datasets/time-series/demo/popest/intercensal-2000-2010-cities-and-towns.html>
 #' @noRd
 #' @examples
 #' str(uspop2000)
@@ -16,13 +17,13 @@
 #' plot(Lat ~ Long, data = uspop2000, cex = sqrt(p), asp = 1, col = rgb(1, 0, 0, .3))
 
 if (FALSE) {
-uspop2000 <- NULL
-if (file.exists("inst/csv/uspop2000.csv")) {
-  uspop2000 <- read.csv(
-    text = readLines("inst/csv/uspop2000.csv", encoding = "UTF-8"),
-    stringsAsFactors = FALSE
-  )
-}
+  uspop2000 <- NULL
+  if (file.exists("inst/csv/uspop2000.csv")) {
+    uspop2000 <- utils::read.csv(
+      text = readLines("inst/csv/uspop2000.csv", encoding = "UTF-8"),
+      stringsAsFactors = FALSE
+    )
+  }
 }
 
 #' @docType data
@@ -31,18 +32,20 @@ if (file.exists("inst/csv/uspop2000.csv")) {
 #' @description Atlantic Ocean storms 2005
 #' @details This dataset contains storm tracks for selected storms
 #' in the Atlantic Ocean basin for the year 2005
-#' @format \code{sp::SpatialLinesDataFrame}
+#' @format `sf` object
+#' @family built in datasets
 NULL
 
 #' @docType data
 #' @name gadmCHE
 #' @title Administrative borders of Switzerland (level 1)
 #' @description Administrative borders of Switzerland (level 1)
-#' @details This dataset comes from \url{https://gadm.org}.
-#' It was downloaded using \code{\link{getData}}.
-#' @format \code{sp::SpatialPolygonsDataFrame}
+#' @details This dataset comes from <https://gadm.org>.
+#' It was downloaded using [raster::getData()].
+#' @format `sf` object
+#' @family built in datasets
 #' @source
-#' \url{https://gadm.org}
+#' <https://gadm.org>
 NULL
 
 #'
@@ -54,5 +57,6 @@ NULL
 #' subset of a larger database that was compiled by students at the
 #' University of Marburg for a seminar called
 #' "The Geography of Beer, sustainability in the food industry"
-#' @format \code{sp::SpatialPointsDataFrame}
+#' @format `sf` object
+#' @family built in datasets
 NULL
