@@ -35,8 +35,9 @@ normalize_multipolygon <- function(df) {
   df
 }
 
-test_that("normalize", {
-  skip_if_not_installed("sf")
+test_that("normalize sp", {
+  rlang::local_options("rlib_warning_verbosity" = "verbose")
+  skip_if_not_installed("sp")
 
   library(sf)
   library(sp)
@@ -47,24 +48,19 @@ test_that("normalize", {
     leaflet(x) %>% addTiles() %>% addPolygons()
   }
 
-  poldata <- st_as_sf(gadmCHE)
+  poldata <- gadmCHE
 
   (r1 <- pgontest(poldata))
   (r2 <- pgontest(st_geometry(poldata)))
   (r3 <- pgontest(st_geometry(poldata)[[1]]))
   (r4 <- pgontest(st_geometry(poldata)[[1]][[1]] %>% st_polygon()))
-  (r5 <- pgontest(gadmCHE))
-  (r6 <- pgontest(polygons(gadmCHE)))
-  (r7 <- pgontest(polygons(gadmCHE)@polygons[[1]]))
-  (r8 <- pgontest(polygons(gadmCHE)@polygons[[1]]@Polygons[[1]]))
 
   expect_maps_equal(r1, r2)
   expect_maps_equal(r3, r4)
-  expect_maps_equal(r1, r5)
 
   ### lines -----------------------------------------------------------------
 
-  lindata <- st_as_sf(atlStorms2005)
+  lindata <- atlStorms2005
 
   plinetest <- function(x) {
     leaflet(x) %>% addTiles() %>% addPolylines()
@@ -74,19 +70,11 @@ test_that("normalize", {
   (l2 <- plinetest(st_geometry(lindata)))  # sfc_LINESTRING, sfc
   (l3 <- plinetest(st_geometry(lindata)[[1]]))  # XY, LINESTRING, sfg
   (l4 <- plinetest(st_multilinestring(st_geometry(lindata))))  # XY, MULTILINESTRING, sfg
-  (l5 <- plinetest(atlStorms2005))
-  (l6 <- plinetest(SpatialLines(atlStorms2005@lines)))
-  (l7 <- plinetest(atlStorms2005@lines[[1]]))
-  (l8 <- plinetest(atlStorms2005@lines[[1]]@Lines[[1]]))
 
   expect_maps_equal(l1, l2)
-  expect_maps_equal(l1, l5)
-  expect_maps_equal(l1, l6)
-  expect_maps_equal(l3, l7)
-  expect_maps_equal(l3, l8)
 
   ### points ----------------------------------------------------------------
-  ptsdata <- st_as_sf(breweries91)
+  ptsdata <- breweries91
   class(ptsdata)  # sf, data.frame
   class(st_geometry(ptsdata))  # sfc_POINT, sfc
   class(st_geometry(ptsdata)[[1]])  # XY, POINT, sfg
@@ -107,7 +95,7 @@ test_that("normalize", {
 
   ### lines -----------------------------------------------------------------
   polys <-
-    Polygons(list(
+    sp::Polygons(list(
       create_square(),
       create_square(, 5, 5),
       create_square(1, hole = TRUE),
@@ -116,7 +104,7 @@ test_that("normalize", {
     ), "A")
   comment(polys) <- "0 0 1 2 2"
 
-  spolys <- SpatialPolygons(list(
+  spolys <- sp::SpatialPolygons(list(
     polys
   ))
   stspolys <- st_as_sf(spolys)
@@ -142,7 +130,7 @@ test_that("normalize", {
   (l104 <- leaflet(stspolys) %>% addPolylines())
   expect_maps_equal(l103, l104)
 
-  slines <- SpatialLines(list(
+  slines <- sp::SpatialLines(list(
     Lines(list(
       create_square(type = Line),
       create_square(, 5, 5, type = Line),
